=============================
 oslo.messaging Release Notes
=============================

.. toctree::
   :maxdepth: 1

   unreleased
   yoga
   xena
   wallaby
   victoria
   ussuri
   train
   stein
   rocky
   queens
   pike
   ocata
   newton
